==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_create_group_request_body.py <==
# coding: utf-8

import re
import six





class KeystoneCreateGroupRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'group': 'KeystoneCreateGroupOption'
    }

    attribute_map = {
        'group': 'group'
    }

    def __init__(self, group=None):
        """KeystoneCreateGroupRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._group = None
        self.discriminator = None

        self.group = group

    @property
    def group(self):
        """Gets the group of this KeystoneCreateGroupRequestBody.


        :return: The group of this KeystoneCreateGroupRequestBody.
        :rtype: KeystoneCreateGroupOption
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this KeystoneCreateGroupRequestBody.


        :param group: The group of this KeystoneCreateGroupRequestBody.
        :type: KeystoneCreateGroupOption
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneCreateGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_create_group_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KeystoneCreateGroupRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'group': 'KeystoneCreateGroupOption'
    }

    attribute_map = {
        'group': 'group'
    }

    def __init__(self, group=None):
        """KeystoneCreateGroupRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._group = None
        self.discriminator = None

        self.group = group

    @property
    def group(self):
        """Gets the group of this KeystoneCreateGroupRequestBody.


        :return: The group of this KeystoneCreateGroupRequestBody.
        :rtype: KeystoneCreateGroupOption
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this KeystoneCreateGroupRequestBody.


        :param group: The group of this KeystoneCreateGroupRequestBody.
        :type: KeystoneCreateGroupOption
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneCreateGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
